<template>
  <basic-container style="width: 100%">
    <v-chart :options="chartOptions" :auto-resize="true" id="chart"></v-chart>
    <div style="display: inline-block;float: right;margin-bottom: 10px;margin-right: 60px">
      <el-button size="small" type="primary" plain @click="delHandler">删除</el-button>
    </div>
  </basic-container>
</template>

<script>
import 'echarts'
import 'echarts/lib/chart/bar' // 导入柱状图组件
import 'echarts/lib/component/tooltip'
import 'echarts/lib/component/legend'
import {deleteChartId} from "@/api/statistic/chart"
export default {
  name: "polarBarChart",
  props:{
    pieData:{
      type:Array,
      default:[]
    },
    chartName:{
      type:String,
      default: ""
    },
    monthData:{
      type:Array,
      default: () => ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月']
    },
    btmname :{
      type: String
    }
  },
  watch:{
    pieData:{
      immediate:true,
      handler(newval, oldval){
        if (newval) {
          const series = [
            {
              type: 'bar',
              name: '新增',
              data: newval[1],
              coordinateSystem: 'polar',
              stack: 'a',
              emphasis: {
                focus: 'series'
              },
              itemStyle: {
                color: '#91cc75' // 新增的颜色
              }
            },
            {
              type: 'bar',
              name: '总量',
              data: newval[0],
              coordinateSystem: 'polar',
              stack: 'a',
              emphasis: {
                focus: 'series'
              },
              itemStyle: {
                color: '#5470c6' // 总量的颜色
              }
            }
          ];
          this.chartOptions.series = series;
        }
      }
    },
    chartName:{
      handler(newval, oldval){
        if(newval){
          this.chartOptions.title.text = newval + "数据统计"
        }
      },
      immediate:true
    }
  },
  data() {
    return {
      chartOptions: {
        title: {
          text: '',
        },
        legend: {
          data: ['总量', '新增'],
        },
        polar: {},
        angleAxis: {
          type: 'category',
          data: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月']
        },
        radiusAxis: {},
        tooltip: {
          trigger: 'axis'
        },
        series: []
      }
    }
  },
  created(){
    this.chartOptions.color = ['#5470c6', '#91cc75', '#fac858', '#ca8622', '#ee6666', '#73c0de', '#3ba272', '#fc8452', '#9a60b4'];
  },
  methods:{
    delHandler(){
      deleteChartId({btmname:this.btmname,chartId:'1'}).then(res=>{
        this.$message.success('删除成功')
        this.$emit('refresh');
      }).catch(error=>{
        this.$message.error(error)
      })
    }
  }
}
</script>

<style scoped lang="scss">
#chart {
  width: 97%;
  height: 530px;
}
</style>
